@@ -14,12 +14,13 @@
 from flask import request
 from datetime import datetime
 from flask import current_app as app
-from common import parse, payload
+from common import parse, payload, ratelimit
 from eve.utils import document_link, config, document_etag
 from eve.auth import requires_auth
 from eve.validation import ValidationError
 
 
+@ratelimit()
 @requires_auth('resource')
 def post(resource):
     """ Adds one or more documents to a resource. Each document is validated
@@ -30,16 +31,25 @@ def post(resource):
 
     :param resource: name of the resource involved.
 
+    .. versionchanged: 0.0.7
+       Support for Rate-Limiting.
+       Support for 'extra_response_fields'.
+
+       'on_posting' and 'on_posting_<resource>' events are raised before the
+       documents are inserted into the database. This allows callback functions
+       to arbitrarily edit/update the documents being stored.
+
     .. versionchanged:: 0.0.6
-        Support for bulk inserts.
-        Please note: validation constraints are checked against the database,
-        and not between the payload documents themselves. This causes an
-        interesting corner case: in the event of a multiple documents payload
-        where two or more documents carry the same value for a field where the
-        'unique' constraint is set, the payload will validate successfully, as
-        there are no duplicates in the database (yet). If this is an issue, the
-        client can always send the documents once at a time for insertion, or
-        validate locally before submitting the payload to the API.
+       Support for bulk inserts.
+
+       Please note: validation constraints are checked against the database,
+       and not between the payload documents themselves. This causes an
+       interesting corner case: in the event of a multiple documents payload
+       where two or more documents carry the same value for a field where the
+       'unique' constraint is set, the payload will validate successfully, as
+       there are no duplicates in the database (yet). If this is an issue, the
+       client can always send the documents once at a time for insertion, or
+       validate locally before submitting the payload to the API.
 
     .. versionchanged:: 0.0.5
        Support for 'application/json' Content-Type .
@@ -53,8 +63,8 @@ def post(resource):
     """
 
     date_utc = datetime.utcnow().replace(microsecond=0)
-
-    schema = app.config['DOMAIN'][resource]['schema']
+    resource_def = app.config['DOMAIN'][resource]
+    schema = resource_def['schema']
     validator = app.validator(schema, resource)
     documents = []
     issues = []
@@ -74,8 +84,7 @@ def post(resource):
 
                 # if 'user-restricted resource access' is enabled and there's
                 # an Auth request active, inject the username into the document
-                username_field = \
-                    app.config['DOMAIN'][resource]['auth_username_field']
+                username_field = resource_def['auth_username_field']
                 if username_field and request.authorization:
                     document[username_field] = request.authorization.username
 
@@ -94,8 +103,11 @@ def post(resource):
         if len(doc_issues) == 0:
             documents.append(document)
 
-    # bulk insert
     if len(documents):
+        # notify callbacks
+        getattr(app, "on_posting")(resource, documents)
+        getattr(app, "on_posting_%s" % resource)(documents)
+        # bulk insert
         ids = app.data.insert(resource, documents)
 
     # build response payload
@@ -115,6 +127,12 @@ def post(resource):
                 {'self': document_link(resource,
                                        response_item[config.ID_FIELD])}
 
+            # add any additional field that might be needed
+            allowed_fields = [x for x in resource_def['extra_response_fields']
+                              if x in document.keys()]
+            for field in allowed_fields:
+                response_item[field] = document[field]
+
         response[key] = response_item
 
     return response, None, None, 200
