@@ -10,88 +10,33 @@ from datetime import datetime, timedelta
 from flask.ext.pymongo import MongoClient
 from bson import ObjectId
 from eve import Eve, STATUS_ERR
-from test_settings import MONGO_PASSWORD, MONGO_USERNAME, MONGO_DBNAME,  \
-                          DOMAIN, MONGO_HOST, MONGO_PORT
+from test_settings import MONGO_PASSWORD, MONGO_USERNAME, MONGO_DBNAME, \
+    DOMAIN, MONGO_HOST, MONGO_PORT
 
 
-class TestBase(unittest.TestCase):
+class TestMinimal(unittest.TestCase):
+    """ Start the building of the tests for an application
+    based on Eve by subclassing this class and provide proper settings
+    using :func:`setUp()`
+    """
 
-    def setUp(self):
-        self.known_resource_count = 100
+    def setUp(self, settings_file='eve/tests/test_settings.py'):
+        """ Prepare the test fixture
+
+        :param settings_file: the name of the settings file.  Defaults
+                              to `eve/tests/test_settings.py`.
+        """
+
+        self.known_resource_count = 101
         self.setupDB()
 
-        self.settings_file = 'eve/tests/test_settings.py'
+        self.settings_file = settings_file
         self.app = Eve(settings=self.settings_file)
 
         self.test_client = self.app.test_client()
 
         self.domain = self.app.config['DOMAIN']
 
-        self.known_resource = 'contacts'
-        self.known_resource_url = ('/%s/' %
-                                   self.domain[self.known_resource]['url'])
-        self.empty_resource = 'empty'
-        self.empty_resource_url = '/%s/' % self.empty_resource
-
-        self.unknown_resource = 'unknown'
-        self.unknown_resource_url = '/%s/' % self.unknown_resource
-        self.unknown_item_id = '4f46445fc88e201858000000'
-        self.unknown_item_name = 'unknown'
-
-        self.unknown_item_id_url = ('/%s/%s/' %
-                                    (self.domain[self.known_resource]['url'],
-                                     self.unknown_item_id))
-        self.unknown_item_name_url = ('/%s/%s/' %
-                                      (self.domain[self.known_resource]['url'],
-                                      self.unknown_item_name))
-
-        self.readonly_resource = 'payments'
-        self.readonly_resource_url = (
-            '/%s/' % self.domain[self.readonly_resource]['url'])
-
-        self.different_resource = 'users'
-        self.different_resource_url = ('/%s/' %
-                                       self.domain[
-                                           self.different_resource]['url'])
-
-        response, status = self.get('contacts', '?max_results=2')
-        contact = response['_items'][0]
-        self.item_id = contact[self.app.config['ID_FIELD']]
-        self.item_name = contact['ref']
-        self.item_tid = contact['tid']
-        self.item_etag = contact['etag']
-        self.item_ref = contact['ref']
-        self.item_id_url = ('/%s/%s/' %
-                            (self.domain[self.known_resource]['url'],
-                             self.item_id))
-        self.item_name_url = ('/%s/%s/' %
-                              (self.domain[self.known_resource]['url'],
-                               self.item_name))
-        self.alt_ref = response['_items'][1]['ref']
-
-        response, status = self.get('payments', '?max_results=1')
-        self.readonly_id = response['_items'][0]['_id']
-        self.readonly_id_url = ('%s%s/' % (self.readonly_resource_url,
-                                           self.readonly_id))
-
-        response, status = self.get('users')
-        user = response['_items'][0]
-        self.user_id = user[self.app.config['ID_FIELD']]
-        self.user_username = user['username']
-        self.user_name = user['ref']
-        self.user_etag = user['etag']
-        self.user_id_url = ('/%s/%s/' %
-                            (self.domain[self.different_resource]['url'],
-                             self.user_id))
-
-        response, status = self.get('invoices')
-        invoice = response['_items'][0]
-        self.invoice_id = invoice[self.app.config['ID_FIELD']]
-        self.invoice_etag = invoice['etag']
-        self.invoice_id_url = ('/%s/%s/' %
-                               (self.domain['invoices']['url'],
-                                self.invoice_id))
-
     def tearDown(self):
         self.dropDB()
 
@@ -233,9 +178,26 @@ class TestBase(unittest.TestCase):
         self.assertTrue('href' in link)
         self.assertTrue('/%s/' % item_id in link['href'])
 
+    def assertLastLink(self, links, page):
+        if page:
+            self.assertTrue('last' in links)
+            link = links['last']
+            self.assertTrue('title' in link)
+            self.assertTrue('href' in link)
+            self.assertEqual('last page', link['title'])
+            self.assertTrue("page=%d" % page in link['href'])
+        else:
+            self.assertTrue('last' not in links)
+
     def assert400(self, status):
         self.assertEqual(status, 400)
 
+    def assert401(self, status):
+        self.assertEqual(status, 401)
+
+    def assert401or405(self, status):
+        self.assertTrue(status == 401 or 405)
+
     def assert403(self, status):
         self.assertEqual(status, 403)
 
@@ -245,26 +207,96 @@ class TestBase(unittest.TestCase):
     def assert412(self, status):
         self.assertEqual(status, 412)
 
+    def assert500(self, status):
+        self.assertEqual(status, 500)
+
     def setupDB(self):
         self.connection = MongoClient(MONGO_HOST, MONGO_PORT)
         self.connection.drop_database(MONGO_DBNAME)
         if MONGO_USERNAME:
-            self.connection[MONGO_DBNAME].add_user(MONGO_USERNAME, MONGO_PASSWORD)
+            self.connection[MONGO_DBNAME].add_user(MONGO_USERNAME,
+                                                   MONGO_PASSWORD)
         self.bulk_insert()
 
     def bulk_insert(self):
-        _db = self.connection[MONGO_DBNAME]
-        _db.contacts.insert(self.random_contacts(self.known_resource_count))
-        _db.contacts.insert(self.random_users(2))
-        _db.payments.insert(self.random_payments(10))
-        _db.invoices.insert(self.random_invoices(1))
-        self.connection.close()
+        pass
 
     def dropDB(self):
         self.connection = MongoClient(MONGO_HOST, MONGO_PORT)
         self.connection.drop_database(MONGO_DBNAME)
         self.connection.close()
 
+
+class TestBase(TestMinimal):
+
+    def setUp(self):
+        super(TestBase, self).setUp()
+
+        self.known_resource = 'contacts'
+        self.known_resource_url = ('/%s/' %
+                                   self.domain[self.known_resource]['url'])
+        self.empty_resource = 'empty'
+        self.empty_resource_url = '/%s/' % self.empty_resource
+
+        self.unknown_resource = 'unknown'
+        self.unknown_resource_url = '/%s/' % self.unknown_resource
+        self.unknown_item_id = '4f46445fc88e201858000000'
+        self.unknown_item_name = 'unknown'
+
+        self.unknown_item_id_url = ('/%s/%s/' %
+                                    (self.domain[self.known_resource]['url'],
+                                     self.unknown_item_id))
+        self.unknown_item_name_url = ('/%s/%s/' %
+                                      (self.domain[self.known_resource]['url'],
+                                       self.unknown_item_name))
+
+        self.readonly_resource = 'payments'
+        self.readonly_resource_url = (
+            '/%s/' % self.domain[self.readonly_resource]['url'])
+
+        self.different_resource = 'users'
+        self.different_resource_url = ('/%s/' %
+                                       self.domain[
+                                           self.different_resource]['url'])
+
+        response, status = self.get('contacts', '?max_results=2')
+        contact = response['_items'][0]
+        self.item_id = contact[self.app.config['ID_FIELD']]
+        self.item_name = contact['ref']
+        self.item_tid = contact['tid']
+        self.item_etag = contact['etag']
+        self.item_ref = contact['ref']
+        self.item_id_url = ('/%s/%s/' %
+                            (self.domain[self.known_resource]['url'],
+                             self.item_id))
+        self.item_name_url = ('/%s/%s/' %
+                              (self.domain[self.known_resource]['url'],
+                               self.item_name))
+        self.alt_ref = response['_items'][1]['ref']
+
+        response, status = self.get('payments', '?max_results=1')
+        self.readonly_id = response['_items'][0]['_id']
+        self.readonly_id_url = ('%s%s/' % (self.readonly_resource_url,
+                                           self.readonly_id))
+
+        response, status = self.get('users')
+        user = response['_items'][0]
+        self.user_id = user[self.app.config['ID_FIELD']]
+        self.user_username = user['username']
+        self.user_name = user['ref']
+        self.user_etag = user['etag']
+        self.user_id_url = ('/%s/%s/' %
+                            (self.domain[self.different_resource]['url'],
+                             self.user_id))
+
+        response, status = self.get('invoices')
+        invoice = response['_items'][0]
+        self.invoice_id = invoice[self.app.config['ID_FIELD']]
+        self.invoice_etag = invoice['etag']
+        self.invoice_id_url = ('/%s/%s/' %
+                               (self.domain['invoices']['url'],
+                                self.invoice_id))
+
     def random_contacts(self, num, standard_date_fields=True):
         schema = DOMAIN['contacts']['schema']
         contacts = []
@@ -344,3 +376,11 @@ class TestBase(unittest.TestCase):
                 }
             )
         return rows
+
+    def bulk_insert(self):
+        _db = self.connection[MONGO_DBNAME]
+        _db.contacts.insert(self.random_contacts(self.known_resource_count))
+        _db.contacts.insert(self.random_users(2))
+        _db.payments.insert(self.random_payments(10))
+        _db.invoices.insert(self.random_invoices(1))
+        self.connection.close()
