@@ -2,6 +2,7 @@
 
 from eve.tests import TestBase
 import simplejson as json
+from eve.utils import api_prefix
 
 
 class TestRenders(TestBase):
@@ -53,40 +54,57 @@ class TestRenders(TestBase):
         self.assertEqual(r.headers['Access-Control-Allow-Origin'],
                          'http://example.com, http://1on1.com')
 
-    def test_CORS_OPTIONS(self):
-        r = self.test_client.open('/', method='OPTIONS')
+    def test_CORS_OPTIONS(self, url='/', methods=[]):
+        r = self.test_client.open(url, method='OPTIONS')
         self.assertFalse('Access-Control-Allow-Origin' in r.headers)
         self.assertFalse('Access-Control-Allow-Methods' in r.headers)
         self.assertFalse('Access-Control-Allow-Max-Age' in r.headers)
+        self.assert200(r.status_code)
 
         self.app.config['X_DOMAINS'] = '*'
-        r = self.test_client.open('/', method='OPTIONS',
+        r = self.test_client.open(url, method='OPTIONS',
                                   headers=[('Origin', 'http://example.com')])
+        self.assert200(r.status_code)
         self.assertEqual(r.headers['Access-Control-Allow-Origin'], '*')
+        for m in methods:
+            self.assertTrue(m in r.headers['Access-Control-Allow-Methods'])
 
         self.app.config['X_DOMAINS'] = ['http://example.com',
                                         'http://1on1.com']
-        r = self.test_client.open('/', method='OPTIONS',
+        r = self.test_client.open(url, method='OPTIONS',
                                   headers=[('Origin', 'http://example.com')])
+        self.assert200(r.status_code)
         self.assertEqual(r.headers['Access-Control-Allow-Origin'],
                          'http://example.com, http://1on1.com')
 
+        for m in methods:
+            self.assertTrue(m in r.headers['Access-Control-Allow-Methods'])
+
         self.assertTrue('Access-Control-Allow-Origin' in r.headers)
         self.assertTrue('Access-Control-Allow-Max-Age' in r.headers)
 
-        r = self.test_client.get('/', headers=[('Origin',
+        r = self.test_client.get(url, headers=[('Origin',
                                                 'http://not_an_example.com')])
+        self.assert200(r.status_code)
         self.assertEqual(r.headers['Access-Control-Allow-Origin'],
                          'http://example.com, http://1on1.com')
+        for m in methods:
+            self.assertTrue(m in r.headers['Access-Control-Allow-Methods'])
 
-        r = self.test_client.open('/', method='OPTIONS',
-                                  headers=[('Origin',
-                                            'http://not_an_example.com')])
-        self.assertEqual(r.headers['Access-Control-Allow-Origin'],
-                         'http://example.com, http://1on1.com')
+    def test_CORS_OPTIONS_resources(self):
+        prefix = api_prefix(self.app.config['URL_PREFIX'],
+                            self.app.config['API_VERSION'])
+
+        for resource, settings in self.app.config['DOMAIN'].items():
+
+            # resource endpoint
+            url = '%s/%s/' % (prefix, settings['url'])
+            methods = settings['resource_methods'] + ['OPTIONS']
+            self.test_CORS_OPTIONS(url, methods)
 
 
 class TestEventHooks(TestBase):
+    #TODO not sure this is the right place for this class really.
 
     def setUp(self):
         super(TestEventHooks, self).setUp()
@@ -195,6 +213,31 @@ class TestEventHooks(TestBase):
         self.post()
         self.assertTrue(self.passed)
 
+    def test_on_getting(self):
+        def general_hook(resource, documents):
+            self.assertEqual(resource, self.known_resource)
+            self.assertEqual(len(documents), 25)
+            self.passed = True
+        self.app.on_getting += general_hook
+        self.test_client.get(self.known_resource_url)
+        self.assertTrue(self.passed)
+
+    def test_on_getting_resource(self):
+        def resource_hook(documents):
+            self.assertEqual(len(documents), 25)
+            self.passed = True
+        self.app.on_getting_contacts += resource_hook
+        self.test_client.get(self.known_resource_url)
+        self.assertTrue(self.passed)
+
+    def test_on_getting_item(self):
+        def item_hook(resource, _id, document):
+            self.assertEqual(str(_id), self.item_id)
+            self.passed = True
+        self.app.on_getting_item += item_hook
+        self.test_client.get(self.item_id_url)
+        self.assertTrue(self.passed)
+
     def post(self, extra=None):
         headers = [('Content-Type', 'application/x-www-form-urlencoded')]
         data = {'item1': json.dumps({"ref": "0123456789012345678901234"})}
