@@ -16,14 +16,14 @@ class TestResponse(TestBase):
             response = literal_eval(self.r.data)
         except:
             self.fail('standard response cannot be converted to a dict')
-        self.assertIs(type(response), dict)
+        self.assertTrue(isinstance(response, dict))
 
     def test_response_object(self):
-        response = literal_eval(self.r.data).get('response')
-        self.assertEqual(type(response), dict)
+        response = literal_eval(self.r.data)
+        self.assertTrue(isinstance(response, dict))
         self.assertEqual(len(response), 2)
 
-        resource = response.get(self.empty_resource)
-        self.assertEqual(type(resource), list)
-        links = response.get('links')
-        self.assertEqual(type(links), list)
+        resource = response.get('_items')
+        self.assertTrue(isinstance(resource, list))
+        links = response.get('_links')
+        self.assertTrue(isinstance(links, dict))
